#
# spec file for package xflr5
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xflr5
Version:        6.10.04
Release:        4.3
%define short_version 6.10
Summary:        Analysis tool for airfoils and planes operating at low Re numbers
License:        GPL-2.0
Group:          Productivity/Scientific/Other
Url:            http://www.xflr5.com
# Source0:        http://sourceforge.net/projects/%{name}/files/%{version}/%{name}-%{version}_src.tar.gz
Source0:        %{name}-%{version}_src.tar.gz
Source1:        %{name}.desktop
BuildRequires:  Mesa-devel
BuildRequires:  gcc-c++
BuildRequires:  libqt4-devel >= 4.7.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
XFLR5 is a design tool intended for the design and analysis of reduced scaled model airplanes.
It includes the XFoil program for the analysis of airfoils.
It includes a non-linear Lifting Line method (LLT), two Vortex Lattice Methods (VLM),
and a 3D panel flat panel,first-order method for the analysis of wings and planes.
XFLR5 v5 is a re-write of XFLR5 v4 using Qt4 libraries instead of Microsoft's MFC.
XFLR5 v6 introduces stability and control analysis

%prep
%setup -q -n %{name}-%{short_version}
cp %{SOURCE1} .
# fix wrong-file-end-of-line-encoding
sed -i 's/\r$//' {License.txt,doc/ReleaseNotes.txt}

%build
qmake -o Makefile %{name}_%{short_version}.pro
make %{?_smp_mflags}
lrelease %{name}_%{short_version}.pro

%install
install -Dm 755 %{name}               %{buildroot}%{_bindir}/%{name}
install -Dm 644 images/%{name}.png    %{buildroot}%{_datadir}/pixmaps/%{name}.png
install -Dm 644 %{name}.desktop       %{buildroot}%{_datadir}/applications/%{name}.desktop
install -d %{buildroot}%{_datadir}/%{name}/translations
install -m 644 translations/*.qm      %{buildroot}%{_datadir}/%{name}/translations

%files
%defattr(-,root,root)
%doc License.txt doc/ReleaseNotes.txt doc/*.odt
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%changelog
* Sat Apr 18 2015 techwinder@gmail.com
- Update to version 6.10.04.
  * Corrected a potential crash bug when deleting a plane with polars
  * Added a standard ISA model for the calculation of air properties
  * Corrected the issues with the reference lengths after wing scaling
  * Fixed the bugs related to the import operation of a body definition from a text file
  * Fix for retina displays on OS X
  * Corrected the export of plane polars to text files to include the sideslip variable
  * Other minor corrections and improvements
* Mon Mar  2 2015 sfalken@opensuse.org
- Changed Category in .desktop file to clear brp-check-suse failure
* Sat Jun 28 2014 dmitry_r@opensuse.org
- Update to version 6.10.03. Changes sinse version 6.09:
  * Created a new binary .xfl projet file format. Replaces once and
    for all the awful .wpa format
  * Removed the option for independent wing analysis
  * Introducing type 5 polars for the analysis of variable sideslip
  * Disabled the horseshoe vortex method for stability polars, for
    beta-polars, and whenever sidelip is defined.
  * Aligned theviscous drag vector with freestream velocity rather
    than with x-axis - slight impact on viscous results
  * Enabled LLT analysis for all Plane objects
  * Removed the option for symmetry in 3d analysis
  * Corrected the bug in type 4 plane analysis-elevator and fin
    coefficients were incorrectly calculated
  * Removed the default sizing for panel and matrix arrays. The
    arrays are now allocated for the size of the largest model
    loaded in the session.
  * Corrected some memory leaks
  * Corrected memory allocation/release mismatches
  * MASSIVE code cleaning.
  * Created GUI-independant classes for 3D-panel analysis and LLT
    analysis
  * Minor corrections and enhancements
* Wed Dec 26 2012 dmitry_r@opensuse.org
- Update to version 6.09
  * see included ReleaseNotes.txt for details
- spec file cleanup
* Tue Jun 26 2012 adeperrois@xflr5.com
- xflr5 v6.07
  * fixed type 2 batch polar analysis
  * fixed the issue with incorrect 3D-panel calculations
  * Corrected the incorrect aileron control derivatives
  * Corrected the bug in wing analysis with ground effect
  * Corrected the bug in type 4 analysis for wings and planes
  * Corrected the bug which modified the chord length as twist increases:
    impact results for wings with high dihedral
  * Cleaned, corrected, and improved the code for B-Splines
  * Removed the option for Min/Max type controls in Stabillity Polars
  * Added an option to edit Wing Polar paramaters
  * Fixed the crash bug when defining wings with more than 16 span sections
  * Corrected a bug leading to incorrect results in stability derivatives
    with active controls (CPanel::RotateBC())
  * Removed the Splined Points Foil option
  * Other minor corrections and enhancements
  * Code cleaning
* Fri Jan  6 2012 adeperrois@xflr5.com
- xflr5 v6.06
  * Minor corrections and improvements
* Sun Jul 24 2011 adeperrois@xflr5.com
- xflr5 v6.05 beta, July 15th, 2011
  * For Type 7 polars, listed the control value instead of the aoa in the top drop down box
  * Added a calculation form to determine Re.sqrt(Cl) for foil Type 2 polars
  * Added the Japanese translation to the repository - thanks to Koichi
  * Minor corrections and improvements
* Sun May 15 2011 adeperrois@xflr5.com
- xflr5 v6.04 beta, May 14th, 2011
  * added a settings save at each project save
  * added and option to view forces on panels as coloured arrows
  * fixed the incorrect setting of AVL-type controls for flaps in T7 analysis
  * added the missing write operation in the project file of the control variable for wing operating points
  * modified the setting of boundary conditions in T7 analysis with activated controls - impact on balanced aoa
  * modified the wing construction process to allow for a gap in the middle of the wing
  * corrected the bug which caused the disapperance of the left stability toolbar when switching to 3D view
  * corrected the bug which prevented from changing the default number of panels in naca foil generation
  * continued the code cleaning process
* Sun Feb 13 2011 adeperrois@xflr5.com
- XFLR5v6.03 beta rpm release
  * modified the geometry connection between panels with dihedral and twist - may slightly impact the results
  * corrected the calculations with sideslip
  * added multi-threading capability for foil batch analysis
  * added an option to display the position of point masses in 3d-view
  * in the export to AVL of point masses, corrected the missing addition of wing x & z position
  * modified the export format to AVL of with wing flaps
  * added an option to highlight the currently selected operating point, or the mode in root locs view
  * changed the interface for stability analysis
  * added a properties dialog box option for operating points
  * corrected various minor bugs
  * made several minor enhancements
* Sun Dec 19 2010 adeperrois@xflr5.com
- XFLR5v6.02 beta rpm release
  * added an option to load a background image in the foil direct design module
  * corrected some errors in CoG and inertia automatic calculations, with impact on results
  * did some deep code cleaning
  * re-organized the panel analysis code to perform only one far field calculation per operating point
  * optimized the panel method for increased speed of execution
  * corrected the mesh edition for NURBS bodies
  * changed the export format for graphs
  * implemented the stability method for mixed panel/vlm method
  * implemented the stability method for full 3D panel method
  * corrected the bug which lead to incorrect results in 3D panel with Neumann B.C.
  * corrected the error in the jump in potential at the wing's trailing edage in full 3d panel method
  * set the estimation of inertia properties at the time of polar definition instead of evaluating at the time of analysis
  * fixed the bug which could cause a crash when dragging a point in splines design
  * corrected the asymetric transition location for symetric wings
  * corrected the source strength influence of thick panels on thin surfaces, with impact on results for planes with body
  * corrected the Cp 3D color display for VLM2 analysis
  * added the influence of pressure forces acting on the body to induced pitching moment coefficient
  * added calculation of neutral point position based on Cma/Cza ratio
  * corrected various minor bugs
  * made several minor enhancements
* Thu Oct 14 2010 adeperrois@xflr5.com
- XFLR5v6.01 beta rpm release
  * Corrected the incorrect balance speed in 3D type 2 polars for planes
  * Corrected the final moment calculation in stability analysis
  * Corrected the incorrect lift calculation in stability analysis
* Sun Sep 19 2010 adeperrois@xflr5.com
- XFLR5v6.00 beta rpm release
* Sat Apr  3 2010 adeperrois@xflr5.com
- First rpm release
